from python_on_whales.client_config import DockerCLICaller


class AppCLI(DockerCLICaller):
    def bundle(self):
        """Not yet implemented"""
        raise NotImplementedError

    def init(self):
        """Not yet implemented"""
        raise NotImplementedError

    def inspect(self):
        """Not yet implemented"""
        raise NotImplementedError

    def install(self):
        """Not yet implemented"""
        raise NotImplementedError

    def list(self):
        """Not yet implemented"""
        raise NotImplementedError

    def merge(self):
        """Not yet implemented"""
        raise NotImplementedError

    def pull(self):
        """Not yet implemented"""
        raise NotImplementedError

    def push(self):
        """Not yet implemented"""
        raise NotImplementedError

    def render(self):
        """Not yet implemented"""
        raise NotImplementedError

    def split(self):
        """Not yet implemented"""
        raise NotImplementedError

    def status(self):
        """Not yet implemented"""
        raise NotImplementedError

    def uninstall(self):
        """Not yet implemented"""
        raise NotImplementedError

    def upgrade(self):
        """Not yet implemented"""
        raise NotImplementedError

    def validate(self):
        """Not yet implemented"""
        raise NotImplementedError

    def version(self):
        """Not yet implemented"""
        raise NotImplementedError
